Class: Prawn::Table::Cells
- Inherits:
-
Array
- Object
- Array
- Prawn::Table::Cells
- Defined in:
- lib/prawn/table/cells.rb
Overview
Represents a selection of cells to be styled. Operations on a CellProxy can be chained, and cell properties can be set one-for-all on the proxy.
To set vertical borders only:
table.cells.borders = [:left, :right]
To highlight a rectangular area of the table:
table.rows(1..3).columns(2..4).background_color = 'ff0000'
Instance Method Summary collapse
-
#[](row, col) ⇒ Object
Retrieves a cell based on its 0-based row and column.
-
#columns(row_spec) ⇒ Object
(also: #column)
Limits selection to the given column or columns.
-
#filter(&block) ⇒ Object
Allows you to filter the given cells by arbitrary properties.
-
#height ⇒ Object
Returns the total height of all rows in the selected set.
-
#max_width ⇒ Object
Returns maximum width that can contain cells in the set.
-
#method_missing(id, *args, &block) ⇒ Object
Supports setting arbitrary properties on a group of cells.
-
#min_width ⇒ Object
Returns minimum width required to contain cells in the set.
-
#rows(row_spec) ⇒ Object
(also: #row)
Limits selection to the given row or rows.
-
#style(options = {}, &block) ⇒ Object
Supports setting multiple properties at once.
-
#width ⇒ Object
Returns the total width of all columns in the selected set.
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(id, *args, &block) ⇒ Object
Supports setting arbitrary properties on a group of cells.
table.cells.row(3..6).background_color = 'cc0000'
161 162 163 |
# File 'lib/prawn/table/cells.rb', line 161 def method_missing(id, *args, &block) each { |c| c.send(id, *args, &block) } end |
Instance Method Details
#[](row, col) ⇒ Object
Retrieves a cell based on its 0-based row and column. Returns an individual Cell, not a Cells collection.
table.cells[0, 0].content # => "First cell content"
88 89 90 |
# File 'lib/prawn/table/cells.rb', line 88 def [](row, col) find { |c| c.row == row && c.column == col } end |
#columns(row_spec) ⇒ Object Also known as: column
Limits selection to the given column or columns. col_spec can be
anything that responds to the === operator selecting a set of 0-based
column numbers; most commonly a number or a range.
table.column(0) # selects first column
table.columns(3..4) # selects columns four and five
68 69 70 71 |
# File 'lib/prawn/table/cells.rb', line 68 def columns(row_spec) index_cells unless @indexed Cells.new(@columns[row_spec] ||= select{ |c| row_spec === c.column }) end |
#filter(&block) ⇒ Object
Allows you to filter the given cells by arbitrary properties.
table.column(4).filter { |cell| cell.content =~ /Yes/ }.
background_color = '00ff00'
79 80 81 |
# File 'lib/prawn/table/cells.rb', line 79 def filter(&block) Cells.new(select(&block)) end |
#height ⇒ Object
Returns the total height of all rows in the selected set.
148 149 150 151 152 153 154 155 |
# File 'lib/prawn/table/cells.rb', line 148 def height row_heights = {} each do |cell| row_heights[cell.row] = [row_heights[cell.row], cell.height].compact.max end row_heights.values.inject(0) { |sum, width| sum + width } end |
#max_width ⇒ Object
Returns maximum width that can contain cells in the set.
137 138 139 140 141 142 143 144 |
# File 'lib/prawn/table/cells.rb', line 137 def max_width column_max_widths = {} each do |cell| column_max_widths[cell.column] = [column_max_widths[cell.column], cell.max_width].compact.min end column_max_widths.values.inject(0) { |sum, width| sum + width } end |
#min_width ⇒ Object
Returns minimum width required to contain cells in the set.
126 127 128 129 130 131 132 133 |
# File 'lib/prawn/table/cells.rb', line 126 def min_width column_min_widths = {} each do |cell| column_min_widths[cell.column] = [column_min_widths[cell.column], cell.min_width].compact.max end column_min_widths.values.inject(0) { |sum, width| sum + width } end |
#rows(row_spec) ⇒ Object Also known as: row
Limits selection to the given row or rows. row_spec can be anything
that responds to the === operator selecting a set of 0-based row
numbers; most commonly a number or a range.
table.row(0) # selects first row
table.rows(3..4) # selects rows four and five
55 56 57 58 |
# File 'lib/prawn/table/cells.rb', line 55 def rows(row_spec) index_cells unless @indexed Cells.new(@rows[row_spec] ||= select{ |c| row_spec === c.row }) end |
#style(options = {}, &block) ⇒ Object
Supports setting multiple properties at once.
table.cells.style(:padding => 0, :border_width => 2)
is the same as:
table.cells.padding = 0
table.cells.border_width = 2
You can also pass a block, which will be called for each cell in turn. This allows you to set more complicated properties:
table.cells.style { |cell| cell.border_width += 12 }
106 107 108 109 110 111 |
# File 'lib/prawn/table/cells.rb', line 106 def style(={}, &block) each do |cell| .each { |k, v| cell.send("#{k}=", v) } block.call(cell) if block end end |
#width ⇒ Object
Returns the total width of all columns in the selected set.
115 116 117 118 119 120 121 122 |
# File 'lib/prawn/table/cells.rb', line 115 def width column_widths = {} each do |cell| column_widths[cell.column] = [column_widths[cell.column], cell.width].compact.max end column_widths.values.inject(0) { |sum, width| sum + width } end |